import { PrimaryGeneratedColumn, Column } from "typeorm";
import {
  IsInt,
  IsNotEmpty,
  IsOptional,
  IsPositive,
} from "class-validator";
import { Participant } from "./Participant";

/**
 * Defines the donation interface.
*/
export abstract class Donation {
  /**
   * Autogenerated unique id (primary key).
   */
  @PrimaryGeneratedColumn()
  @IsOptional()
  @IsInt()
  id: number;

  /**
   * The donations's donor.
   */
  @Column()
  @IsNotEmpty()
  //TODO: Relationship
  donor: Participant;

  /**
   * The donation's amount in cents (or whatever your currency's smallest unit is.).
   * The exact implementation may differ for each type of donation.
   */
  abstract amount: number;
}