import { Entity, PrimaryGeneratedColumn, Column } from "typeorm";
import {
  IsInt,
  IsNotEmpty,
  IsOptional,
  IsPositive,
  IsString,
} from "class-validator";

/**
 * Defines a track of given length.
*/
@Entity()
export class Track {
  /**
   * Autogenerated unique id (primary key).
   */
  @PrimaryGeneratedColumn()
  @IsOptional()
  @IsInt()
  id: number;

  /**
   * The track's name.
   */
  @Column()
  @IsString()
  @IsNotEmpty()
  name: string;

  /**
   * The track's length/distance in meters.
   */
  @Column()
  @IsInt()
  @IsPositive()
  distance: number;
}
